@@ -24,11 +24,11 @@ from typing import (
     Callable,
     Dict,
     Iterable,
-    Tuple,
     List,
     Mapping,
     Optional,
     Sequence,
+    Tuple,
     Union,
 )
 
@@ -37,7 +37,7 @@ import py
 from nox import _typing
 from nox._decorators import Func
 from nox.logger import logger
-from nox.virtualenv import CondaEnv, ProcessEnv, VirtualEnv, PassthroughEnv
+from nox.virtualenv import CondaEnv, PassthroughEnv, ProcessEnv, VirtualEnv
 
 if _typing.TYPE_CHECKING:
     from nox.manifest import Manifest
@@ -70,6 +70,36 @@ def _normalize_path(envdir: str, path: Union[str, bytes]) -> str:
     return full_path
 
 
+def _dblquote_pkg_install_args(args: Tuple[str, ...]) -> Tuple[str, ...]:
+    """Double-quote package install arguments in case they contain '>' or '<' symbols"""
+
+    # routine used to handle a single arg
+    def _dblquote_pkg_install_arg(pkg_req_str: str) -> str:
+        # sanity check: we need an even number of double-quotes
+        if pkg_req_str.count('"') % 2 != 0:
+            raise ValueError(
+                "ill-formated argument with odd number of quotes: %s" % pkg_req_str
+            )
+
+        if "<" in pkg_req_str or ">" in pkg_req_str:
+            if pkg_req_str[0] == '"' and pkg_req_str[-1] == '"':
+                # already double-quoted string
+                return pkg_req_str
+            else:
+                # need to double-quote string
+                if '"' in pkg_req_str:
+                    raise ValueError(
+                        "Cannot escape requirement string: %s" % pkg_req_str
+                    )
+                return '"%s"' % pkg_req_str
+        else:
+            # no dangerous char: no need to double-quote string
+            return pkg_req_str
+
+    # double-quote all args that need to be and return the result
+    return tuple(_dblquote_pkg_install_arg(a) for a in args)
+
+
 class _SessionQuit(Exception):
     pass
 
@@ -131,10 +161,16 @@ class Session:
         """The python version passed into ``@nox.session``."""
         return self._runner.func.python
 
+    @property
+    def bin_paths(self) -> Optional[List[str]]:
+        """The bin directories for the virtualenv."""
+        return self.virtualenv.bin_paths
+
     @property
     def bin(self) -> Optional[str]:
-        """The bin directory for the virtualenv."""
-        return self.virtualenv.bin
+        """The first bin directory for the virtualenv."""
+        paths = self.bin_paths
+        return paths[0] if paths is not None else None
 
     def create_tmp(self) -> str:
         """Create, and return, a temporary directory."""
@@ -225,6 +261,34 @@ class Session:
 
         return self._run(*args, env=env, **kwargs)
 
+    def run_always(
+        self, *args: str, env: Mapping[str, str] = None, **kwargs: Any
+    ) -> Optional[Any]:
+        """Run a command **always**.
+
+        This is a variant of :meth:`run` that runs in all cases, including in
+        the presence of ``--install-only``.
+
+        :param env: A dictionary of environment variables to expose to the
+            command. By default, all environment variables are passed.
+        :type env: dict or None
+        :param bool silent: Silence command output, unless the command fails.
+            ``False`` by default.
+        :param success_codes: A list of return codes that are considered
+            successful. By default, only ``0`` is considered success.
+        :type success_codes: list, tuple, or None
+        :param external: If False (the default) then programs not in the
+            virtualenv path will cause a warning. If True, no warning will be
+            emitted. These warnings can be turned into errors using
+            ``--error-on-external-run``. This has no effect for sessions that
+            do not have a virtualenv.
+        :type external: bool
+        """
+        if not args:
+            raise ValueError("At least one argument required to run_always().")
+
+        return self._run(*args, env=env, **kwargs)
+
     def _run(self, *args: str, env: Mapping[str, str] = None, **kwargs: Any) -> Any:
         """Like run(), except that it runs even if --install-only is provided."""
         # Legacy support - run a function given.
@@ -251,9 +315,11 @@ class Session:
             kwargs["external"] = True
 
         # Run a shell command.
-        return nox.command.run(args, env=env, path=self.bin, **kwargs)
+        return nox.command.run(args, env=env, paths=self.bin_paths, **kwargs)
 
-    def conda_install(self, *args: str, **kwargs: Any) -> None:
+    def conda_install(
+        self, *args: str, auto_offline: bool = True, **kwargs: Any
+    ) -> None:
         """Install invokes `conda install`_ to install packages inside of the
         session's environment.
 
@@ -268,6 +334,10 @@ class Session:
             session.conda_install('--file', 'requirements.txt')
             session.conda_install('--file', 'requirements-dev.txt')
 
+        By default this method will detect when internet connection is not
+        available and will add the `--offline` flag automatically in that case.
+        To disable this behaviour, set `auto_offline=False`.
+
         To install the current package without clobbering conda-installed
         dependencies::
 
@@ -292,11 +362,28 @@ class Session:
         if not args:
             raise ValueError("At least one argument required to install().")
 
+        # Escape args that should be (conda-specific; pip install does not need this)
+        args = _dblquote_pkg_install_args(args)
+
         if "silent" not in kwargs:
             kwargs["silent"] = True
 
+        extraopts = ()  # type: Tuple[str, ...]
+        if auto_offline and venv.is_offline():
+            logger.warning(
+                "Automatically setting the `--offline` flag as conda repo seems unreachable."
+            )
+            extraopts = ("--offline",)
+
         self._run(
-            "conda", "install", "--yes", *prefix_args, *args, external="error", **kwargs
+            "conda",
+            "install",
+            "--yes",
+            *extraopts,
+            *prefix_args,
+            *args,
+            external="error",
+            **kwargs
         )
 
     def install(self, *args: str, **kwargs: Any) -> None:
